// ************************************************** Common **************************************************
// const COPYRIGHT_YEAR = 1937
// TODO: the actual COPYRIGHT_YEAR has to be inserted somehow (e.g. by the postprocessing script)

const onresize = (dom_elem, callback) => {
  const resizeObserver = new ResizeObserver(() => callback() );
  resizeObserver.observe(dom_elem);
};

const AANALYTICS_SCRIPT_SOURCE = "//assets.adobedtm.com/launch-EN3504a9f210b14bc28b773c8d8c5a022d.min.js"

const ON_RS_DOMAIN = window.location.hostname.endsWith("rohde-schwarz.com");

function addTrackingScript() {
    let js = document.createElement("script");
    js.src = AANALYTICS_SCRIPT_SOURCE;
    js.async = true;
    document.querySelector("head").append(js);    
}

function redirectLogoLink() {
    var logoWrapper = document.querySelector("div.logo-wrapper");
    logoWrapper.querySelector("a.logo").setAttribute("href", "https://www.rohde-schwarz.com");
}

function fixSearchEncoding() {
	var searchInputField = document.querySelector('form.search input');
	var searchSubmitDiv = document.querySelector("div.search-submit");
	searchInputField.addEventListener("keypress", function(e) {
		if (e.keyCode===13) {
			encodeInputField(searchInputField);
		}
	}, true);
	searchSubmitDiv.addEventListener("click", function() {
		encodeInputField(searchInputField);
	}, true);
}

function encodeInputField(inputField) {
	if(inputField.value!="") {
		inputField.style.visibility='hidden';
		inputField.value = encodeURI(inputField.value);
	}
}

function decodeInputField(inputField) {
	if(inputField.value!="") {
		inputField.style.visibility='hidden';
		inputField.value = decodeURI(inputField.value);
		inputField.style.visibility='visible';
	}
}

function preserveSidenavWidth() {
    if (typeof(Storage) !== "undefined") {
        var sidenavWrapperDiv = document.querySelector('div.sidenav-wrapper');
        if(sessionStorage.getItem("sidenavWrapperDiv.width")) {
            sidenavWrapperDiv.style.width = sessionStorage.getItem("sidenavWrapperDiv.width");
        }
        onresize(sidenavWrapperDiv, function () {
            sessionStorage.setItem("sidenavWrapperDiv.width", sidenavWrapperDiv.style.width);
        })
    }
}

function insertWebFooterAfter(element) {
    var cy = (typeof COPYRIGHT_YEAR !== 'undefined'? COPYRIGHT_YEAR: new Date().getFullYear());
    element.insertAdjacentHTML('beforeend',
    '<div class="web-footer"><hr/>' +
    '<table><colgroup><col/><col/></colgroup><tbody><tr>' +
    '<td><a href="https://www.rohde-schwarz.com/imprint\">Imprint</a> | <a href="https://www.rohde-schwarz.com/statement-of-privacy">Statement of privacy</a> | <a href="https://www.rohde-schwarz.com/terms-of-website-use">Terms of website use</a></td>' +
    '<td>&#169; ' + cy + ' ROHDE &amp; SCHWARZ</td></tr></tbody></table>');
}
// ************************************************** Common **************************************************

window.addEventListener('load', function () {
	let searchInputField = document.querySelector('form.search input');
	decodeInputField(searchInputField);
	fixSearchEncoding();
	preserveSidenavWidth();
    var thumbnail_elems = document.getElementsByClassName('MCPopupThumbnail');
    var sizePattern = /_thumb_(\d+)_\1\.[^.]*$/;
    var threshold = null;
    [].forEach.call(thumbnail_elems, function (img) {
        var img_width = img.getAttribute('data-mc-width');
        var img_height = img.getAttribute('data-mc-height');
        if (! threshold) {
            var match = sizePattern.exec(img.getAttribute('src'));
            if (match) {
                threshold = parseInt(match[1]);
            } else {
                threshold = 225;
            }
        }
        if (img_width < threshold && img_height < threshold) {
            img.setAttribute('src', img.parentElement.getAttribute('href'));
            img.setAttribute('width', img_width);
            img.setAttribute('height', img_height);
            $(img).on("click", function () {
                return false;
            });
            img.parentElement.removeAttribute('href');
        } else {
            var zoomInIcon = document.createElement("img");
            zoomInIcon.src = "Resources/workspace/img/Icon_zoom_in_24_bright.svg";
            zoomInIcon.title = "Maximize";
            zoomInIcon.classList.add("zoom_icon")
            img.parentElement.appendChild(zoomInIcon);
            $(img.parentElement).on("click", "*", function () {
                setTimeout(function () {
                    var zoomOutIcon = document.createElement("img");
                    zoomOutIcon.src = "Resources/workspace/img/Icon_zoom_out_24_bright.svg";
                    zoomOutIcon.title = "Minimize";
                    zoomOutIcon.classList.add("zoom_icon")
                    var popup_elems = document.getElementsByClassName('MCPopupContainer');
                    [].forEach.call(popup_elems, function (popUp) {                        
                        popUp.appendChild(zoomOutIcon);
                        if (popUp.querySelectorAll('.caption')[0]) {
                            var oldcaption = popUp.parentElement.parentElement.querySelectorAll('.caption')[0];
                            popUp.removeChild(oldcaption);
                        }
                        var caption = img.parentElement.parentElement.querySelectorAll('.caption')[0];
                        if (caption) {
                            popUp.appendChild(caption.cloneNode(true));
                        }
                        var legend = img.parentElement.parentElement.querySelectorAll('.legend')[0];
                        if (legend) {
                            popUp.appendChild(legend.cloneNode(true));
                        }
                    });
                });
            });
        }
    });
    if (ON_RS_DOMAIN) {
        redirectLogoLink();
        insertWebFooterAfter(document.getElementById("mainbody"));
        // digitalData is inserted by the postprocessing script
        if (typeof digitalData !== 'undefined') {
            addTrackingScript();
        }
    }
})

window.onhashchange = locationHashChanged;

function locationHashChanged() {
    if (window.location.hash != "") {
        var target = document.getElementById(window.location.hash.substr(1));
        if (target != null && target.tagName === "SECTION" && target.getAttribute("class") === "function") {
            window.location.hash = target.getElementsByTagName("h1")[0].id
        }
    }
}
